@@ -35,7 +35,8 @@ class GeoLibRequestHandler:
         response = requests.request("GET", url, headers=self.headers, params=querystring)
 
         data = json.loads(response.text)
-        currency = data['data']['code']
+        currency = data['data'][0]['code']
+
 
         return currency
 
